# Summary of 1 files

## KnownCorruptedFile

```
basket: has fNevBuf=0 but fEntryOffset=0, pos=871492569, len=89625, fNbytes=0, fObjlen=0, trying to repair
```

This file is known to contain some corrupt events. It likely cannot be recovered for this production however we typically don't delete these files as other analyses might not depend on the bad branches.

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `251878` | `LFN:/lhcb/LHCb/Collision18/BHADRON.MDST/00075555/0000/00075555_00002848_1.bhadron.mdst` | 973453832 | **LCG.RAL.uk** (1) | 1.9 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision18%2FLOG%2F00251878%2F0000&task_name=00001553) | 1 / 11 |
